@@ -1,6 +1,6 @@
 package Bundle::CVSMonitor;
 
-$VERSION = 1.01;
+$VERSION = 1.02;
 
 1;
 
@@ -26,8 +26,6 @@ Chart::Math::Axis  - Calculate correct graph axis
 
 Clone
 
-Cwd
-
 Class::Autouse     - Dynamic module loading
 
 Class::Default
@@ -76,15 +74,6 @@ URI::Escape
 
 Validate::Net
 
-=head1 DESCRIPTION
-
-This bundle provides a correct install of all modules needed to
-get the application CVS Monitor working.
-
-Yes, we use a lot of shit. Some of these won't get used directly, but are used
-for the AppSpac run-time library, which I've bundled into this install. It has
-a few more esoteric needs
-
 =head1 AUTHOR
 
 Adam Kennedy E<lt>F<cvsmonitor@ali.as>E<gt>
